@@ -1,4 +1,4 @@
-# 0.1.1
+# 0.0.40
 ##################################################################################
 #   MIT License
 #
@@ -32,7 +32,10 @@ import sys
 from concurrent.futures import ThreadPoolExecutor
 from time import sleep, strftime, time
 import urllib3
-
+##############
+import getpass
+import shutil
+import stat
 
 # logging.basicConfig(level=logging.DEBUG, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
 
@@ -59,8 +62,40 @@ os.chdir(os.path.dirname(os.path.abspath(__file__)))  # go to .py script folder
 
 exit_app = False
 urllib3.disable_warnings()
+
 # print(sys.version)
 
+
+def switch_dst_dir(container):  # if app runs in a container
+
+    username = getpass.getuser()
+    # print(username)
+    if container == 'SNAP':
+        ghetto_folder = '//home//' + username + '//GhettoRecorder'
+    else:
+        ghetto_folder = '//tmp//GhettoRecorder'  # DOCKER
+
+    source_ini = os.path.dirname(os.path.abspath(__file__)) + '//settings.ini'
+    source_script = os.path.dirname(os.path.abspath(__file__)) + '//startGhettoRecorder'
+    dst_ini = ghetto_folder + '//settings.ini'
+    dst_script = ghetto_folder + '//startGhettoRecorder'
+
+    access_rights = 0o755
+    try:
+        os.mkdir(ghetto_folder, access_rights)
+    except FileExistsError:
+        pass
+
+    try:
+        if not os.path.exists(dst_ini):
+            shutil.copyfile(source_ini, dst_ini)
+            shutil.copyfile(source_script, dst_script)
+    except FileExistsError:
+        pass
+    st = os.stat(dst_script)
+    os.chmod(dst_script, st.st_mode | stat.S_IEXEC)
+
+
 def signal_handler(sig, frame):
     global exit_app
     print(' Stop recording ...')
@@ -76,7 +111,9 @@ class GBase:
     sleeper = 2
     pool = ThreadPoolExecutor(200)
     radio_base_dir = os.path.dirname(os.path.abspath(__file__)) + '//radiostations'  # if not set set_radio_base_dir()
-    settings_path = os.path.dirname(os.path.abspath(__file__)) + '//settings.ini'  # if not  set in set_settings_path()
+    # radio_base_dir = ghetto_folder
+    settings_path = os.path.dirname(os.path.abspath(__file__)) + '//settings.ini'  # if not set in set_settings_path()
+    # settings_path = radio_base_dir + '//settings.ini'
     path = os.getcwd()
     path_to = path + '//'
     timer = 0
@@ -140,14 +177,13 @@ class GBase:
 
 
 class GIni(GBase):
-
-    ini_keys = {}        # cls attribute to store selections from ini file, works because of key[key] = value, else not
+    ini_keys = {}  # cls attribute to store selections from ini file, works because of key[key] = value, else not
     srv_param_dict = {}  # all ini keys plus short url, suffix, server type stuff
-    song_dict = {}       # recorder reads song title from key, related to the url in settings.ini
+    song_dict = {}  # recorder reads song title from key, related to the url in settings.ini
     start_stop_recording = {}  # ini key: 'start' , 'stop'; while loop check start, working check stop go upper while
     # ini_key + '_single_title', ini_key + '_rec_from_here'
     cost_current_ini = ''  # ini key for cost_dict calc
-    cost_dict = {}        # stores len of received headers to calc amount of data searching strings per day
+    cost_dict = {}  # stores len of received headers to calc amount of data searching strings per day
     fail_meta_dict = {}  # can not read metadata from stream, no data
     # list of search strings delimiter blank, first key is named 'STRINGS': Britney Phantom ไม่เคยจะจำ Elton Jim techno
     search_dict = {'STRINGS': 'Britney Spears ไม่เคยจะจำ Elton AC/DC techno Band feat. mix'}  # only show it is working
@@ -230,17 +266,16 @@ class GIni(GBase):
 
 
 class GNet(GBase):
-    
     is_shoutcast_server = False
     is_icecast_server = False
     is_icecast_json = False
     is_unknown_server = False
     is_no_meta_data_avail = False
-    
+
     http_pool = urllib3.PoolManager(num_pools=200)
     request = ''
     ua_standard = {'Icy-MetaData': '1', 'user-agent': "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 "
-                      "(KHTML, like Gecko) Chrome/52.0.2743.82 Safari/537.36"}
+                                                      "(KHTML, like Gecko) Chrome/52.0.2743.82 Safari/537.36"}
     query_shoutcast = '/currentsong'
 
     def __init__(self):
@@ -263,10 +298,18 @@ class GNet(GBase):
             sys.exit()
 
         if url[-4:] == '.m3u' or url[-4:] == '.pls':  # or url[-5:] == '.m3u8' or url[-5:] == '.xspf':
-            read_url = GNet.http_pool.request('GET', url, preload_content=False)
-            print(' \n        --- | ---')
-            print(read_url.read().decode('utf-8'), end="")
+            response = GNet.http_pool.request('GET', url, preload_content=False)
+
+            response_data_split_by_line = response.read().decode("utf-8").splitlines()
             print(" \n        --- | ---")
+
+            for _ in response_data_split_by_line:
+                try:
+                    print(_)
+                except UnicodeEncodeError:
+                    pass
+            print(" \n        --- | ---")
+
             try:
                 play_list_server = input('copy and paste a server from above, here ->: ')
             except Exception as ex:
@@ -278,10 +321,10 @@ class GNet(GBase):
             return False
 
         return play_list_server.strip()
- 
+
     @staticmethod
     def is_shout_ice_unknown_server(server_port, full_url):
-        
+
         response = GNet.is_server_alive(server_port)
         if not response:
             print(' is_server_alive ' + server_port + 'Can not get the server. Exit')
@@ -326,7 +369,7 @@ class GNet(GBase):
 
         except Exception as ke:
             print('   --> server failed, no recording ' + url)
-            print(repl(ke))
+            print(ke)
             return False
         else:
             if GNet.request.status != 200:
@@ -400,12 +443,12 @@ class GNet(GBase):
 
         try:
             request = GNet.http_pool.request('GET', server_name + '/status-json.xsl', preload_content=False)
-            #print(f' 1is_server_icecast_status_json ')
+            # print(f' 1is_server_icecast_status_json ')
             song_title = GNet.ice_status_json(request)
-            #print(f'2is_server_icecast_status_json  {song_title}')
+            # print(f'2is_server_icecast_status_json  {song_title}')
             GNet.is_icecast_server = True
             GNet.is_icecast_json = True
-        
+
         except Exception as ex:
             print(ex)
             print(' server got no readable json file \n will read from stream directly \n')
@@ -441,7 +484,6 @@ class GNet(GBase):
 
 
 class GRecorder:
-
     stream_song_name = '_no-name-record_no_split_'
     path_to_song_dict = {}  # each thread writes the new title to the station key name {station : title}
 
@@ -646,6 +688,18 @@ class GRecorder:
 def step1_collect_stream_server():
     # collect the keys from settings.ini, test if server is alive
     # produce a dictionary with key: short name, value: url
+    try:
+        if os.environ["SNAP"]:
+            print('GR in Ubuntu Snap Container')
+            switch_dst_dir('SNAP')
+    except KeyError:
+        pass
+    try:
+        if os.environ["DOCKER"]:
+            print('GR in Docker Container')  # set var in Dockerfile DOCKER=True
+            switch_dst_dir('DOCKER')
+    except KeyError:
+        pass
 
     GIni.show_items_ini_file()  # print to terminal
     valid_input = False
@@ -703,7 +757,7 @@ def step2_test_stream_server(ini_keys):
     for key in ini_keys:
         test_stream_server(key)
     # print(GIni.srv_param_dict)
-    calc_connection_cost()
+    # calc_connection_cost()
     record(ini_keys, GIni.srv_param_dict)  # this loops at end for signal
 
 
@@ -748,14 +802,12 @@ def test_stream_server(key):
 
 
 def calc_connection_cost():
-
     for item in GIni.cost_dict:
         print(f' key: {item} Bytes: {GIni.cost_dict[item]}, title search only - cost per/hour: '
-              f'{round(((int(GIni.cost_dict[item]) * 30 * 60)/1024) /1024, 2)}mb')
+              f'{round(((int(GIni.cost_dict[item]) * 30 * 60) / 1024) / 1024, 2)}mb')
 
 
 def print_stream_server():
-
     print(f'GIni.srv_param_dict {GIni.srv_param_dict}')
 
 
@@ -764,7 +816,6 @@ def record(ini_keys, path_dict_srv_params):
     signal.signal(signal.SIGINT, signal_handler)
 
     for ini_key in ini_keys:
-
         GIni.song_dict[ini_key] = '_no-name-record_no_split_'  # init the dict for this thread
         GIni.start_stop_recording[ini_key] = 'start'
         # GIni.start_stop_recording[ini_key] = 'stop'            # init it here, should be set via user interface
@@ -772,14 +823,13 @@ def record(ini_keys, path_dict_srv_params):
 
         url = GIni.ini_keys[ini_key]
         GRecorder.path_to_song_dict = GIni.song_dict
-        print(f' <<<<<<<<<<<<<<< GRecorder.path_to_song_dict: {GRecorder.path_to_song_dict}')
+        # print(f' <<<<<<<<<<<<<<< GRecorder.path_to_song_dict: {GRecorder.path_to_song_dict}')
 
         GBase.pool.submit(GRecorder.thread_pull_song_name, url, ini_key, path_dict_srv_params, None)
 
         dir_save = GBase.radio_base_dir + '//' + ini_key
         stream_suffix = path_dict_srv_params[ini_key + '_file']
-        print(
-            f' url,{url} dir_save:{dir_save} stream_suffix: {stream_suffix} ini_key: {ini_key} to_song_dict:{GRecorder.path_to_song_dict}')
+
         GBase.pool.submit(GRecorder.record_songs, url, dir_save, stream_suffix, ini_key, None)
 
     while not GBase.exit_app:
